==> mdemos.server-0.1.0dev.tar.gz: mdemos.server-0.1.0dev/mdemos/server/controllers/root.py <==
# -*- coding: utf-8 -*-
"""Main Controller"""

from tg import expose, flash, require, url, request, redirect, tmpl_context
from pylons.i18n import ugettext as _, lazy_ugettext as l_
from tgext.admin.tgadminconfig import TGAdminConfig
from tgext.admin.controller import AdminController
from repoze.what import predicates

from mdemos.server.lib.base import BaseController
from mdemos.server.model import DBSession, metadata
from mdemos.server import model

from mdemos.server.controllers.secure import SecureController
from mdemos.server.controllers.error import ErrorController
from mdemos.server.controllers.apps import AppController
from mdemos.server.controllers.widgets import WidgetController

__all__ = ['RootController']

import moksha.utils


class RootController(BaseController):

    apps = AppController()
    widgets = WidgetController()
    error = ErrorController()
    moksha_admin = SecureController()

    @expose('mako:mdemos.server.templates.index')
    def index(self, *args, **kw):

        from moksha.ext.turbogears import global_resources
        tmpl_context.moksha_global_resources = global_resources

        # TODO -- should 'menus' be baked right into moksha?  Probably not.
        tmpl_context.menu_widget = moksha.utils.menus.get('default_menu', None)

        return dict(title='[ Moksha ]')


class OldRootController(BaseController):
    """
    The root controller for the mdemos.server application.

    All the other controllers and WSGI applications should be mounted on this
    controller. For example::

        panel = ControlPanelController()
        another_app = AnotherWSGIApplication()

    Keep in mind that WSGI applications shouldn't be mounted directly: They
    must be wrapped around with :class:`tg.controllers.WSGIAppController`.

    """
    secc = SecureController()

    admin = AdminController(model, DBSession, config_type=TGAdminConfig)

    error = ErrorController()

    @expose('mdemos.server.templates.index')
    def index(self):
        """Handle the front-page."""
        return dict(page='index')

    @expose('mdemos.server.templates.about')
    def about(self):
        """Handle the 'about' page."""
        return dict(page='about')

    @expose('mdemos.server.templates.environ')
    def environ(self):
        """This method showcases TG's access to the wsgi environment."""
        return dict(environment=request.environ)

    @expose('mdemos.server.templates.data')
    @expose('json')
    def data(self, **kw):
        """This method showcases how you can use the same controller
        for a data page and a display page"""
        return dict(params=kw)

    @expose('mdemos.server.templates.authentication')
    def auth(self):
        """Display some information about auth* on this application."""
        return dict(page='auth')

    @expose('mdemos.server.templates.index')
    @require(predicates.has_permission('manage', msg=l_('Only for managers')))
    def manage_permission_only(self, **kw):
        """Illustrate how a page for managers only works."""
        return dict(page='managers stuff')

    @expose('mdemos.server.templates.index')
    @require(predicates.is_user('editor', msg=l_('Only for the editor')))
    def editor_user_only(self, **kw):
        """Illustrate how a page exclusive for the editor works."""
        return dict(page='editor stuff')

    @expose('mdemos.server.templates.login')
    def login(self, came_from=url('/')):
        """Start the user login."""
        login_counter = request.environ['repoze.who.logins']
        if login_counter > 0:
            flash(_('Wrong credentials'), 'warning')
        return dict(page='login', login_counter=str(login_counter),
                    came_from=came_from)

    @expose()
    def post_login(self, came_from='/'):
        """
        Redirect the user to the initially requested page on successful
        authentication or redirect her back to the login page if login failed.

        """
        if not request.identity:
            login_counter = request.environ['repoze.who.logins'] + 1
            redirect('/login',
                params=dict(came_from=came_from, __logins=login_counter))
        userid = request.identity['repoze.who.userid']
        flash(_('Welcome back, %s!') % userid)
        redirect(came_from)

    @expose()
    def post_logout(self, came_from=url('/')):
        """
        Redirect the user to the initially requested page on logout and say
        goodbye as well.

        """
        flash(_('We hope to see you soon!'))
        redirect(came_from)

==> mdemos.server-1.0.0dev.tar.gz: mdemos.server-1.0.0dev/mdemos/server/controllers/root.py <==
# -*- coding: utf-8 -*-
"""Main Controller"""

from tg import expose, flash, require, url, request, redirect, tmpl_context
from pylons.i18n import ugettext as _, lazy_ugettext as l_
from tgext.admin.tgadminconfig import TGAdminConfig
from tgext.admin.controller import AdminController
from repoze.what import predicates

from mdemos.server.lib.base import BaseController
from mdemos.server.model import DBSession, metadata
from mdemos.server import model

from mdemos.server.controllers.secure import SecureController
from mdemos.server.controllers.error import ErrorController
from mdemos.server.controllers.apps import AppController
from mdemos.server.controllers.widgets import WidgetController

__all__ = ['RootController']

import moksha.common.utils


class RootController(BaseController):

    apps = AppController()
    widgets = WidgetController()
    error = ErrorController()
    moksha_admin = SecureController()

    @expose('mako:mdemos.server.templates.index')
    def index(self, *args, **kw):

        from moksha.wsgi.ext.turbogears import global_resources
        tmpl_context.moksha_global_resources = global_resources

        # TODO -- should 'menus' be baked right into moksha?  Probably not.
        tmpl_context.menu_widget = moksha.common.utils.menus.get('default_menu', None)

        return dict(title='[ Moksha ]')


class OldRootController(BaseController):
    """
    The root controller for the mdemos.server application.

    All the other controllers and WSGI applications should be mounted on this
    controller. For example::

        panel = ControlPanelController()
        another_app = AnotherWSGIApplication()

    Keep in mind that WSGI applications shouldn't be mounted directly: They
    must be wrapped around with :class:`tg.controllers.WSGIAppController`.

    """
    secc = SecureController()

    admin = AdminController(model, DBSession, config_type=TGAdminConfig)

    error = ErrorController()

    @expose('mdemos.server.templates.index')
    def index(self):
        """Handle the front-page."""
        return dict(page='index')

    @expose('mdemos.server.templates.about')
    def about(self):
        """Handle the 'about' page."""
        return dict(page='about')

    @expose('mdemos.server.templates.environ')
    def environ(self):
        """This method showcases TG's access to the wsgi environment."""
        return dict(environment=request.environ)

    @expose('mdemos.server.templates.data')
    @expose('json')
    def data(self, **kw):
        """This method showcases how you can use the same controller
        for a data page and a display page"""
        return dict(params=kw)

    @expose('mdemos.server.templates.authentication')
    def auth(self):
        """Display some information about auth* on this application."""
        return dict(page='auth')

    @expose('mdemos.server.templates.index')
    @require(predicates.has_permission('manage', msg=l_('Only for managers')))
    def manage_permission_only(self, **kw):
        """Illustrate how a page for managers only works."""
        return dict(page='managers stuff')

    @expose('mdemos.server.templates.index')
    @require(predicates.is_user('editor', msg=l_('Only for the editor')))
    def editor_user_only(self, **kw):
        """Illustrate how a page exclusive for the editor works."""
        return dict(page='editor stuff')

    @expose('mdemos.server.templates.login')
    def login(self, came_from=url('/')):
        """Start the user login."""
        login_counter = request.environ['repoze.who.logins']
        if login_counter > 0:
            flash(_('Wrong credentials'), 'warning')
        return dict(page='login', login_counter=str(login_counter),
                    came_from=came_from)

    @expose()
    def post_login(self, came_from='/'):
        """
        Redirect the user to the initially requested page on successful
        authentication or redirect her back to the login page if login failed.

        """
        if not request.identity:
            login_counter = request.environ['repoze.who.logins'] + 1
            redirect('/login',
                params=dict(came_from=came_from, __logins=login_counter))
        userid = request.identity['repoze.who.userid']
        flash(_('Welcome back, %s!') % userid)
        redirect(came_from)

    @expose()
    def post_logout(self, came_from=url('/')):
        """
        Redirect the user to the initially requested page on logout and say
        goodbye as well.

        """
        flash(_('We hope to see you soon!'))
        redirect(came_from)
